==> pi4j-core-2.1.0-sources.jar: com/pi4j/extension/Plugin.java <==
package com.pi4j.extension;

/*-
 * #%L
 * **********************************************************************
 * ORGANIZATION  :  Pi4J
 * PROJECT       :  Pi4J :: LIBRARY  :: Java Library (CORE)
 * FILENAME      :  Plugin.java
 *
 * This file is part of the Pi4J project. More information about
 * this project can be found here:  https://pi4j.com/
 * **********************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

import com.pi4j.context.Context;
import com.pi4j.exception.InitializeException;
import com.pi4j.exception.ShutdownException;

/**
 * <p>Plugin interface.</p>
 *
 * @author Robert Savage (<a href="http://www.savagehomeautomation.com">http://www.savagehomeautomation.com</a>)
 * @version $Id: $Id
 */
public interface Plugin  {
    /**
     * <p>initialize.</p>
     *
     * @param service a {@link com.pi4j.extension.PluginService} object.
     * @throws InitializeException if error occurs initializing the plugin
     */
    void initialize(PluginService service) throws InitializeException;

    /**
     * <p>shutdown.</p>
     *
     * @param context a {@link com.pi4j.context.Context} object.
     * @throws ShutdownException if an error occurs shutting down the plugin
     */
    default void shutdown(Context context) throws ShutdownException {
        // do nothing <optional override>
    }
}

==> pi4j-core-2.6.0-sources.jar: com/pi4j/extension/Plugin.java <==
package com.pi4j.extension;

/*-
 * #%L
 * **********************************************************************
 * ORGANIZATION  :  Pi4J
 * PROJECT       :  Pi4J :: LIBRARY  :: Java Library (CORE)
 * FILENAME      :  Plugin.java
 *
 * This file is part of the Pi4J project. More information about
 * this project can be found here:  https://pi4j.com/
 * **********************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

import com.pi4j.context.Context;
import com.pi4j.exception.InitializeException;
import com.pi4j.exception.ShutdownException;

/**
 * <p>Plugin interface.</p>
 *
 * @author Robert Savage (<a href="http://www.savagehomeautomation.com">http://www.savagehomeautomation.com</a>)
 * @version $Id: $Id
 */
public interface Plugin  {
    /**
     * <p>initialize.</p>
     *
     * @param service a {@link com.pi4j.extension.PluginService} object.
     * @throws InitializeException if error occurs initializing the plugin
     */
    void initialize(PluginService service) throws InitializeException;

    /**
     * <p>shutdown.</p>
     *
     * @param context a {@link com.pi4j.context.Context} object.
     * @throws ShutdownException if an error occurs shutting down the plugin
     */
    default void shutdown(Context context) throws ShutdownException {
        // do nothing <optional override>
    }

    /**
     * <p>Returns true if this plugin is a mock plugin, and shouldn't generally be used</p>
     *
     * @return a boolean
     */
    default boolean isMock() {
        return false;
    }
}
